@@ -4,8 +4,9 @@ from slai.base_handler import BaseModelHandler
 from slai.login import Login
 from slai import loaders
 from slai.model import Model
+from slai.dataset import DataSet
 
-__version__ = "0.1.39"
+__version__ = "0.1.42"
 
 
 # most used slai actions go here
@@ -13,13 +14,14 @@ model = Model
 model_version = ModelVersion
 loaders = loaders
 inputs = ModelInputs
-BaseModelHandler = BaseModelHandler
 login = Login
-
+dataset = DataSet
+BaseModelHandler = BaseModelHandler
 
 __all__ = [
     "__version__",
     "model_version",
+    "dataset",
     "model",
     "inputs",
     "base_handler",
