@@ -237,7 +237,6 @@ class SlaiCliClient:
         self,
         *,
         model_version_id,
-        model_data,
         artifact_type,
         artifact_notebook,
         artifact_requirements,
@@ -246,7 +245,6 @@ class SlaiCliClient:
         body = {
             "action": "create",
             "model_version_id": model_version_id,
-            "model_data": model_data,
             "artifact_type": artifact_type,
             "artifact_notebook": artifact_notebook,
             "artifact_requirements": artifact_requirements,
@@ -265,6 +263,40 @@ class SlaiCliClient:
         res.raise_for_status()
         return res.json()
 
+    def upload_model_artifact(
+        self,
+        *,
+        model_artifact_id,
+        upload_url,
+        model_data,
+    ):
+        body = {
+            "action": "update",
+            "model_artifact_id": model_artifact_id,
+            "artifact_verified": True,
+        }
+
+        # First upload the artifact
+        res = requests.put(
+            f"{upload_url}",
+            data=model_data,
+            timeout=REQUESTS_TIMEOUT,
+        )
+        res.raise_for_status()
+
+        # Then update the artifact state
+        res = requests.post(
+            f"{self.BASE_URL}/cli/model-artifact",
+            auth=HTTPBasicAuth(self.client_id, self.client_secret),
+            headers={
+                "User-Agent": self.user_agent_header,
+            },
+            json=body,
+            timeout=REQUESTS_TIMEOUT,
+        )
+        res.raise_for_status()
+        return res.json()
+
     def create_model_deployment(
         self,
         *,
@@ -359,94 +391,39 @@ class SlaiCliClient:
         res.raise_for_status()
         return res.json()
 
+    def retrieve_dataset(self, *, name, public, create):
+        body = {"action": "retrieve", "name": name, "public": public, "create": create}
 
-class MockSlaiCliClient:
-    BASE_URL = from_config(
-        key="BASE_URL",
-        default="https://6zacu5yc29.execute-api.us-east-1.amazonaws.com/development",
-    )
+        body = {k: v for k, v in body.items() if v is not None}
+        res = requests.post(
+            f"{self.BASE_URL}/cli/dataset",
+            auth=HTTPBasicAuth(self.client_id, self.client_secret),
+            headers={
+                "User-Agent": self.user_agent_header,
+            },
+            json=body,
+            timeout=REQUESTS_TIMEOUT,
+        )
+        res.raise_for_status()
+        return res.json()
 
-    def __init__(
-        self, *, client_id, client_secret, user_agent_header="SlaiCli smartshare/0.1.0"
-    ):
-        self.client_id = client_id
-        self.client_secret = client_secret
-        self.user_agent_header = user_agent_header
-
-    def create_project(self, name):
-        return {
-            "id": "603299d4dd191a68cfb474ee",
+    def update_dataset(self, *, name, public, diff_table):
+        body = {
+            "action": "update",
             "name": name,
-            "created": "2021-02-21T12:35:16.248099",
-            "updated": "2021-02-21T12:35:16.293876",
+            "public": public,
+            "diff_table": diff_table,
         }
 
-    def retrieve_project(self, *, name):
-        return {
-            "id": "some_project_id",
-            "name": "some_project",
-            "created": "2021-02-21T12:35:16.248099",
-            "updated": "2021-02-21T12:35:16.293876",
-        }
-
-    def update_project(self, name):
-        return {
-            "id": "some_project_id",
-            "name": name,
-            "created": "2021-02-21T12:35:16.248099",
-            "updated": "2021-02-21T12:35:16.293876",
-        }
-
-    def create_model(self, *, project_name, name):
-        return {
-            "id": "60329220dd191a68cfb474ec",
-            "name": name,
-            "model_s3_data_bucket_name": None,
-            "notebook_uri": None,
-            "model_version_id": "60329220dd191a68cfb474ed",
-            "created": "2021-02-21T12:02:24.503850",
-            "updated": "2021-02-21T12:02:24.635203",
-        }
-
-    def retrieve_model(self, *, project_name, name):
-        return {
-            "id": "some_model_id",
-            "name": name,
-            "model_s3_data_bucket_name": None,
-            "notebook_uri": None,
-            "model_version_id": "60329220dd191a68cfb474ed",
-            "created": "2021-02-21T12:02:24.503850",
-            "updated": "2021-02-21T12:02:24.635203",
-        }
-
-    def update_model(self, *, model_data):
-        return model_data
-
-    def create_model_artifact(self, *, model_version_id, model_data, artifact_type):
-        return {
-            "id": "some_model_artifact_id",
-            "model_version_id": model_version_id,
-            "artifact_type": artifact_type,
-            "created": "2021-02-28T12:04:26.737777",
-        }
-
-    def retrieve_model_artifact(self, *, model_version_id, model_artifact_id):
-        return {
-            "id": model_artifact_id,
-            "model_version_id": model_version_id,
-            "artifact_type": "TORCH",
-            "created": "2021-02-28T12:04:26.737777",
-        }
-
-    def create_model_deployment(
-        self,
-        *,
-        model_artifact_id,
-        model_handler_data,
-        model_handler_requirements,
-    ):
-        return {
-            "id": "some_model_id",
-            "created": "2021-02-21T12:02:24.503850",
-            "updated": "2021-02-21T12:02:24.635203",
-        }
+        body = {k: v for k, v in body.items() if v is not None}
+        res = requests.post(
+            f"{self.BASE_URL}/cli/dataset",
+            auth=HTTPBasicAuth(self.client_id, self.client_secret),
+            headers={
+                "User-Agent": self.user_agent_header,
+            },
+            json=body,
+            timeout=REQUESTS_TIMEOUT,
+        )
+        res.raise_for_status()
+        return res.json()
