@@ -76,4 +76,19 @@ class ModelInferenceClient:
         return res.json()
 
     def info(self):
-        pass
+        body = {
+            "model_id": self.model["id"],
+            "model_version_id": self.model_version_id,
+        }
+
+        if body.get("model_version_id") is None:
+            del body["model_version_id"]
+
+        res = requests.post(
+            f"{self.BASE_URL}/model/info",
+            auth=HTTPBasicAuth(self.client_id, self.client_secret),
+            json=body,
+            timeout=REQUESTS_TIMEOUT,
+        )
+        res.raise_for_status()
+        return res.json()
