@@ -1,4 +1,3 @@
-import base64
 import pickle
 
 from slai.loaders import base_loader
@@ -7,7 +6,7 @@ from slai.loaders import base_loader
 class SklearnLoader(base_loader.BaseLoader):
     @classmethod
     def load_model(cls, model_artifact, deployment_instance_path):
-        model_artifact_model_binary = base64.b64decode(model_artifact)
+        model_artifact_model_binary = model_artifact
 
         # write model to deployment instance environment
         model_path = f"{deployment_instance_path}/model"
