@@ -35,5 +35,8 @@ class Model:
     def __call__(self, **inputs):
         return self.inference_client.call(payload=inputs)
 
+    def call(self, **inputs):
+        return self.inference_client.call(payload=inputs)
+
     def info(self):
-        pass
+        return self.inference_client.info()
