@@ -1,4 +1,5 @@
 from slai.loaders.torch_loader import TorchLoader
+from slai.loaders.sklearn_loader import SklearnLoader
 from slai.modules.model_saver import ValidModelFrameworks
 from slai.exceptions import UnsupportedModelFormat
 
@@ -9,11 +10,16 @@ class ModelLoader:
         loaded_model = None
 
         if artifact_type == ValidModelFrameworks.Torch:
-            loaded_model = TorchLoader.load_model(
+            loaded_model, inference_method_name = TorchLoader.load_model(
+                model_artifact=model_artifact,
+                deployment_instance_path=deployment_instance_path,
+            )
+        elif artifact_type == ValidModelFrameworks.Sklearn:
+            loaded_model, inference_method_name = SklearnLoader.load_model(
                 model_artifact=model_artifact,
                 deployment_instance_path=deployment_instance_path,
             )
         else:
             raise UnsupportedModelFormat("invalid_artifact_type")
 
-        return loaded_model
+        return loaded_model, inference_method_name
