@@ -13,6 +13,8 @@ BUILT_INS = [
 
 USE_LATEST = ["torch"]
 
+PACKAGE_MAP = {"sklearn": "scikit-learn"}
+
 
 def get_imports(path):
     with open(path) as fh:
@@ -79,6 +81,11 @@ def generate_requirements_from_runtime(*, module_name):
         )
 
         if requirements is not None and import_line is not None:
+            dist_name = PACKAGE_MAP.get(_base_module_name)
+
+            if dist_name is not None:
+                _base_module_name = dist_name
+
             requirements[_base_module_name] = version
             import_lines.append(import_line)
 
